#
# spec file for package powerd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%define sbindir %_sbindir
%else
%define sbindir /sbin
%endif

Name:           powerd
Version:        2.0.2
Release:        3.1
Summary:        UPS monitoring daemon
License:        GPL-2.0-or-later
Group:          System/Base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  systemd-rpm-macros
URL:            https://power.sourceforge.net/
Source0:        powerd-%{version}.tar.bz2
Source2:        powerd.service
Patch0:         powerd-%{version}.dif
Patch1:         powerd-%{version}-getaddrinfo.patch
Patch2:         powerd-%{version}-gcc14.patch
%if %{undefined _unitdir}
%{expand: %%global %_unitdir %(pkg-config systemd --variable=systemdsystemunitdir)}
%endif

%description -n powerd
powerd monitors the serial port connected to an UPS device and will perform
an unattended shutdown of the system if the UPS is on battery longer
than a specified number of minutes.

%prep
%autosetup -p0

%_fixowner .
%_fixgroup .
/bin/chmod -Rf a+rX,g-w,o-w .

%build
  RPM_OPT_FLAGS="${RPM_OPT_FLAGS} $(getconf LFS_CFLAGS) -pipe"
  CC=%__cc
  export RPM_OPT_FLAGS CC
  %configure --prefix= --bindir='$(DESTDIR)%{sbindir}' \
	--mandir='$(DESTDIR)%{_mandir}' \
	--sbindir='$(DESTDIR)%{sbindir}'
  make %{?_smp_mflags} CFLAGS="-I. $RPM_OPT_FLAGS -DWITH_SYSVINIT"

%install
  mkdir -m 755 -p %{buildroot}/etc
  mkdir -m 755 -p %{buildroot}/sbin
  mkdir -m 755 -p %{buildroot}%{_sbindir}
  mkdir -m 755 -p %{buildroot}%{_mandir}/man8
  make install DESTDIR=%{buildroot}
  echo '# ' > %{buildroot}/etc/powerd.conf
  echo '# /etc/powerd.conf  for powerd version-%{version}' >> %{buildroot}/etc/powerd.conf
  echo '# ' >> %{buildroot}/etc/powerd.conf
  echo '# read manual page of detectups(8) and powerd(8) its self.' >> %{buildroot}/etc/powerd.conf
  echo '# ' >> %{buildroot}/etc/powerd.conf
  echo '# to enable powerd service run the command' >> %{buildroot}/etc/powerd.conf
  echo '#    systemctl enable powerd.service' >> %{buildroot}/etc/powerd.conf
  echo '#    systemctl start  powerd.service' >> %{buildroot}/etc/powerd.conf
  mkdir -p %{buildroot}/%{_unitdir}
  install -m 0644 %{S:2} %{buildroot}/%{_unitdir}/powerd.service
  ln -sf service %{buildroot}%{_sbindir}/rcpowerd

%pre
%service_add_post powerd.service

%preun
%service_del_preun powerd.service

%post
%service_add_post powerd.service

%postun
%service_del_postun powerd.service

%files -n powerd
%defattr (-,root,root,755)
%license COPYING
%doc README SUPPORTED FAQ powerd.conf.monitor powerd.conf.peer
%{sbindir}/powerd
%{sbindir}/detectups
%{_sbindir}/rcpowerd
%config /etc/powerd.conf
%attr(0644,root,root) %{_unitdir}/powerd.service
%doc %{_mandir}/man8/powerd.8.gz
%doc %{_mandir}/man8/detectups.8.gz

%changelog
* Thu Nov  7 2024 Dr. Werner Fink <werner@suse.de>
- Add patch powerd-2.0.2-gcc14.patch
  * Make it build even with gcc14
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- split powerd from sysvinit. patches that were never part
  of powerd but need to be mentioned to pass the bot:
  * startpar-0.58.dif
  * sysvinit-2.88dsf-suse.patch
  * sysvinit-2.90-no-kill.patch
  * sysvinit-2.90.dif
* Wed Jan  4 2023 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Thu Oct 21 2021 Dr. Werner Fink <werner@suse.de>
- Automatic systemd hardening effort by the security team. This has
  not been tested. For details please see
  https://en.opensuse.org/openSUSE:Security_Features#Systemd_hardening_effort
* Wed Nov 25 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Tue Jun 18 2019 Dr. Werner Fink <werner@suse.de>
- Find newer architectures even with vendor string
* Mon Jan 14 2019 Dr. Werner Fink <werner@suse.de>
- Modify patch powerd-2.0.2.dif that is add x86_64-* to match e.g.
  basic mchine type x86_64-suse
* Thu May 24 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Fri Dec  4 2015 sweet_f_a@gmx.de
- cleanup package
* Thu Aug 21 2014 lnussel@suse.de
- use systemd-rpm-macros instead of systemd-devel to avoid build
  dependency on systemd and it's deps in turn
- install rcpowerd link also when using systemd
* Thu Mar 13 2014 werner@suse.de
- Now work with latest systemd
* Wed Jan 15 2014 werner@suse.de
- Correct version number in configuration file
* Tue Jan 14 2014 werner@suse.de
- Split off powerd from sysvinit
- Support systemd unit file
